@@ -176,7 +176,7 @@ glade_project_view_populate_model (GladeProjectView *view)
 	gtk_tree_store_clear (view->priv->model);
 
 	/* Make a list of only the toplevel widgets */
-	for (list = project->objects; list; list = list->next)
+	for (list = (GList *) glade_project_get_objects (project); list; list = list->next)
 	{
 		GObject *object      = G_OBJECT (list->data);
 		GladeWidget *gwidget = glade_widget_get_from_gobject (object);
@@ -608,7 +608,7 @@ glade_project_view_button_press_cb (GtkWidget        *widget,
 			if (widget != NULL &&
 				    event->button == 3)
 			{
-				glade_popup_widget_pop (widget, event, FALSE);
+				glade_popup_widget_pop (widget, event);
 				handled = TRUE;
 			}
 			gtk_tree_path_free (path);
@@ -634,7 +634,6 @@ glade_project_view_cell_function (GtkTreeViewColumn *tree_column,
 				  gpointer data)
 {
 	GPVCellType  type = GPOINTER_TO_INT (data);
-	GdkPixbuf   *small_icon = NULL;
 	GladeWidget *widget;
 	gchar       *text = NULL, *child_type;
 
@@ -647,13 +646,11 @@ glade_project_view_cell_function (GtkTreeViewColumn *tree_column,
 	g_return_if_fail (widget->adaptor != NULL);
 	g_return_if_fail (widget->adaptor->name != NULL);
 
-	g_object_get (widget->adaptor, "small-icon", &small_icon, NULL);
-	g_return_if_fail (small_icon != NULL);
-
 	switch (type) 
 	{
 	case CELL_ICON:
-		g_object_set (G_OBJECT (cell), "pixbuf", small_icon, NULL);
+		g_object_set (G_OBJECT (cell), "icon-name", widget->adaptor->icon_name, NULL);
+		g_object_set (G_OBJECT (cell), "stock-size", GTK_ICON_SIZE_MENU, NULL);
 		break;
 	case CELL_NAME:
 		g_object_set (G_OBJECT (cell), "text", widget->name, NULL);
@@ -673,8 +670,6 @@ glade_project_view_cell_function (GtkTreeViewColumn *tree_column,
 	default:
 		break;
 	}
-
-	g_object_unref (small_icon);
 }
 
 static void
